@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2019 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -21,22 +21,38 @@
 
 package com.github.javaparser.printer;
 
-import com.github.javaparser.ast.CompilationUnit;
-import com.github.javaparser.ast.Node;
-import com.github.javaparser.ast.body.MethodDeclaration;
-import com.github.javaparser.ast.comments.LineComment;
-import com.github.javaparser.ast.expr.*;
-import com.github.javaparser.ast.stmt.Statement;
-import com.github.javaparser.ast.type.Type;
-import org.junit.jupiter.api.Test;
-
 import static com.github.javaparser.StaticJavaParser.parse;
-import static com.github.javaparser.utils.TestParser.*;
 import static com.github.javaparser.utils.TestUtils.assertEqualsStringIgnoringEol;
 import static com.github.javaparser.utils.Utils.SYSTEM_EOL;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
-class PrettyPrintVisitorTest {
+import java.util.Optional;
+
+import org.junit.jupiter.api.Test;
+
+import com.github.javaparser.ParserConfiguration;
+import com.github.javaparser.ast.CompilationUnit;
+import com.github.javaparser.ast.Node;
+import com.github.javaparser.ast.body.MethodDeclaration;
+import com.github.javaparser.ast.comments.LineComment;
+import com.github.javaparser.ast.expr.CastExpr;
+import com.github.javaparser.ast.expr.ClassExpr;
+import com.github.javaparser.ast.expr.Expression;
+import com.github.javaparser.ast.expr.VariableDeclarationExpr;
+import com.github.javaparser.ast.stmt.Statement;
+import com.github.javaparser.ast.type.Type;
+import com.github.javaparser.printer.configuration.ConfigurationOption;
+import com.github.javaparser.printer.configuration.DefaultConfigurationOption;
+import com.github.javaparser.printer.configuration.DefaultPrinterConfiguration;
+import com.github.javaparser.printer.configuration.DefaultPrinterConfiguration.ConfigOption;
+import com.github.javaparser.printer.configuration.PrinterConfiguration;
+import com.github.javaparser.utils.TestParser;
+
+class PrettyPrintVisitorTest extends TestParser {
+
+    private Optional<ConfigurationOption> getOption(PrinterConfiguration config, ConfigOption cOption) {
+        return config.get(new DefaultConfigurationOption(cOption));
+    }
 
     @Test
     void getMaximumCommonTypeWithoutAnnotations() {
@@ -56,15 +72,15 @@ class PrettyPrintVisitorTest {
         assertEquals("int", vde1.getMaximumCommonType().get().toString());
 
         VariableDeclarationExpr vde2 = parseVariableDeclarationExpr("int[]@Foo [] a[], b[]");
-        assertEquals("int[] @Foo [][]", vde2.getMaximumCommonType().get().toString());
+        assertEquals("int[][] @Foo []", vde2.getMaximumCommonType().get().toString());
     }
 
     private String print(Node node) {
-        return new PrettyPrinter().print(node);
+        return new DefaultPrettyPrinter().print(node);
     }
 
-    private String print(Node node, PrettyPrinterConfiguration conf) {
-        return new PrettyPrinter(conf).print(node);
+    private String print(Node node, PrinterConfiguration conf) {
+        return new DefaultPrettyPrinter(conf).print(node);
     }
 
 
@@ -80,7 +96,7 @@ class PrettyPrintVisitorTest {
      */
     @Test
     void printOperatorsR0(){
-        PrettyPrinterConfiguration conf1 = new PrettyPrinterConfiguration().setSpaceAroundOperators(false);
+        PrinterConfiguration conf1 = new DefaultPrinterConfiguration().removeOption(new DefaultConfigurationOption(ConfigOption.SPACE_AROUND_OPERATORS));
         Statement statement1 = parseStatement("a = 1 + 1;");
         assertEquals("a=1+1;", print(statement1, conf1));
     }
@@ -117,19 +133,19 @@ class PrettyPrintVisitorTest {
      */
     @Test
     void printOperatorsR2(){
-        PrettyPrinterConfiguration conf1 = new PrettyPrinterConfiguration().setSpaceAroundOperators(false);
+        PrinterConfiguration conf1 = new DefaultPrinterConfiguration().removeOption(new DefaultConfigurationOption(ConfigOption.SPACE_AROUND_OPERATORS));
         Statement statement1 = parseStatement("a = 1 + 1;");
         assertEquals("a=1+1;", print(statement1, conf1));
 
-        PrettyPrinterConfiguration conf2 = new PrettyPrinterConfiguration().setSpaceAroundOperators(false);
+        PrinterConfiguration conf2 = new DefaultPrinterConfiguration().removeOption(new DefaultConfigurationOption(ConfigOption.SPACE_AROUND_OPERATORS));
         Statement statement2 = parseStatement("a=1+1;");
         assertEquals("a=1+1;", print(statement2, conf2));
 
-        PrettyPrinterConfiguration conf3 = new PrettyPrinterConfiguration().setSpaceAroundOperators(true);
+        PrinterConfiguration conf3 = new DefaultPrinterConfiguration().addOption(new DefaultConfigurationOption(ConfigOption.SPACE_AROUND_OPERATORS));
         Statement statement3 = parseStatement("a = 1 + 1;");
         assertEquals("a = 1 + 1;", print(statement3, conf3));
 
-        PrettyPrinterConfiguration conf4 = new PrettyPrinterConfiguration().setSpaceAroundOperators(true);
+        PrinterConfiguration conf4 = new DefaultPrinterConfiguration().addOption(new DefaultConfigurationOption(ConfigOption.SPACE_AROUND_OPERATORS));
         Statement statement4 = parseStatement("a=1+1;");
         assertEquals("a = 1 + 1;", print(statement4, conf4));
 
@@ -137,7 +153,7 @@ class PrettyPrintVisitorTest {
 
     @Test
     void printOperatorA(){
-        PrettyPrinterConfiguration conf = new PrettyPrinterConfiguration().setSpaceAroundOperators(false);
+        PrinterConfiguration conf = new DefaultPrinterConfiguration().removeOption(new DefaultConfigurationOption(ConfigOption.SPACE_AROUND_OPERATORS));
         Statement statement6 = parseStatement("if(1>2&&1<3||1<3){}");
         assertEquals("if (1>2&&1<3||1<3) {" + SYSTEM_EOL
                 + "}", print(statement6, conf));
@@ -146,7 +162,7 @@ class PrettyPrintVisitorTest {
     @Test
     void printOperator2(){
         Expression expression = parseExpression("1+1");
-        PrettyPrinterConfiguration spaces = new PrettyPrinterConfiguration().setSpaceAroundOperators(false);
+        PrinterConfiguration spaces = new DefaultPrinterConfiguration().removeOption(new DefaultConfigurationOption(ConfigOption.SPACE_AROUND_OPERATORS));
         assertEquals("1+1", print(expression, spaces));
     }
 
@@ -223,7 +239,7 @@ class PrettyPrintVisitorTest {
     void printClassWithoutJavaDocButWithComment() {
         String code = String.format("/** javadoc */ public class A { %s// stuff%s}", SYSTEM_EOL, SYSTEM_EOL);
         CompilationUnit cu = parse(code);
-        PrettyPrinterConfiguration ignoreJavaDoc = new PrettyPrinterConfiguration().setPrintJavadoc(false);
+        PrinterConfiguration ignoreJavaDoc = new DefaultPrinterConfiguration().removeOption(new DefaultConfigurationOption(ConfigOption.PRINT_JAVADOC));
         String content = cu.toString(ignoreJavaDoc);
         assertEquals(String.format("public class A {%s    // stuff%s}%s", SYSTEM_EOL, SYSTEM_EOL, SYSTEM_EOL), content);
     }
@@ -245,7 +261,7 @@ class PrettyPrintVisitorTest {
     void printImportsOrdered() {
         String code = "import x.y.z;import a.b.c;import static b.c.d;class c {}";
         CompilationUnit cu = parse(code);
-        PrettyPrinterConfiguration orderImports = new PrettyPrinterConfiguration().setOrderImports(true);
+        PrinterConfiguration orderImports = new DefaultPrinterConfiguration().addOption(new DefaultConfigurationOption(ConfigOption.ORDER_IMPORTS));
         String content = cu.toString(orderImports);
         assertEqualsStringIgnoringEol("import static b.c.d;\n" +
                 "import a.b.c;\n" +
@@ -360,7 +376,7 @@ class PrettyPrintVisitorTest {
 
         assertEqualsStringIgnoringEol("public class X {\n" +
                 "\n" +
-                "    // line1\n" +
+                "    //   line1\n" +
                 "    void abc() {\n" +
                 "    }\n" +
                 "}\n", cu.toString());
@@ -381,9 +397,9 @@ class PrettyPrintVisitorTest {
         assertEqualsStringIgnoringEol("class A {\n" +
                 "\n" +
                 "    public void helloWorld(String greeting, String name) {\n" +
-                "    // sdfsdfsdf\n" +
-                "    // sdfds\n" +
-                "    /*\n" +
+                "        //sdfsdfsdf\n" +
+                "        //sdfds\n" +
+                "        /*\n" +
                 "                            dgfdgfdgfdgfdgfd\n" +
                 "         */\n" +
                 "    }\n" +
@@ -459,13 +475,16 @@ class PrettyPrintVisitorTest {
 
     @Test
     void printTextBlock() {
-        CompilationUnit cu = parse("class X{String html = \"\"\"\n" +
+        CompilationUnit cu = parseCompilationUnit(
+                ParserConfiguration.LanguageLevel.JAVA_13_PREVIEW,
+                "class X{String html = \"\"\"\n" +
                 "              <html>\n" +
                 "                  <body>\n" +
                 "                      <p>Hello, world</p>\n" +
                 "                  </body>\n" +
                 "              </html>\n" +
-                "              \"\"\";}");
+                "              \"\"\";}"
+        );
 
         assertEqualsStringIgnoringEol("String html = \"\"\"\n" +
                 "    <html>\n" +
@@ -478,12 +497,43 @@ class PrettyPrintVisitorTest {
 
     @Test
     void printTextBlock2() {
-        CompilationUnit cu = parse("class X{String html = \"\"\"\n" +
+        CompilationUnit cu = parseCompilationUnit(
+                ParserConfiguration.LanguageLevel.JAVA_13_PREVIEW,
+                "class X{String html = \"\"\"\n" +
                 "              <html>\n" +
-                "              </html>\"\"\";}");
+                "              </html>\"\"\";}"
+        );
 
         assertEqualsStringIgnoringEol("String html = \"\"\"\n" +
                 "    <html>\n" +
                 "    </html>\"\"\";", cu.getClassByName("X").get().getFieldByName("html").get().toString());
     }
+
+
+    @Test
+    void innerClassWithConstructorReceiverParameterTest() {
+        String innerClassWithConstructorReceiverParam =
+                "public class A {\n\n" +
+                        "    class InnerA {\n\n" +
+                        "        InnerA(A A.this) {\n" +
+                        "        }\n" +
+                        "    }\n" +
+                        "}\n";
+        CompilationUnit cu = parseCompilationUnit(innerClassWithConstructorReceiverParam);
+        assertEqualsStringIgnoringEol(innerClassWithConstructorReceiverParam, print(cu));
+    }
+
+    @Test
+    void printPermitsKeyworld() {
+        CompilationUnit cu = parseCompilationUnit(
+                ParserConfiguration.LanguageLevel.JAVA_17,
+                "public sealed interface I1 permits I2, C, D {}"
+        );
+        String expected =
+        		"public sealed interface I1 permits I2, C, D {\n"
+        		+ "}\n";
+
+
+        assertEqualsStringIgnoringEol(expected, cu.toString());
+    }
 }
